==> thirdparty-service-biz-1.0.33.p2-20211015.034711-1-sources.jar: cn/com/duiba/domain/ZhijiAddCreditsReqBody.java <==
package cn.com.duiba.domain;

/**
 * Created by zhangyongjie on 2021/10/13 11:19 上午
 */
public class ZhijiAddCreditsReqBody {

    private String SourceCode = "DUIBA";

    private String superId = "1000000001788051";

    private String TraceId;

    private String TransactionNumber;

    private String TransactionTime;

    private String TransactionType;

    private ZhijiAddCreditsReqData Data;

    public String getSourceCode() {
        return SourceCode;
    }

    public void setSourceCode(String sourceCode) {
        SourceCode = sourceCode;
    }

    public String getSuperId() {
        return superId;
    }

    public void setSuperId(String superId) {
        this.superId = superId;
    }

    public String getTraceId() {
        return TraceId;
    }

    public void setTraceId(String traceId) {
        TraceId = traceId;
    }

    public String getTransactionNumber() {
        return TransactionNumber;
    }

    public void setTransactionNumber(String transactionNumber) {
        TransactionNumber = transactionNumber;
    }

    public String getTransactionTime() {
        return TransactionTime;
    }

    public void setTransactionTime(String transactionTime) {
        TransactionTime = transactionTime;
    }

    public String getTransactionType() {
        return TransactionType;
    }

    public void setTransactionType(String transactionType) {
        TransactionType = transactionType;
    }

    public ZhijiAddCreditsReqData getData() {
        return Data;
    }

    public void setData(ZhijiAddCreditsReqData data) {
        Data = data;
    }
}

==> thirdparty-service-biz-1.0.59-20220623.034212-1-sources.jar: cn/com/duiba/domain/ZhijiAddCreditsReqBody.java <==
package cn.com.duiba.domain;

import com.alibaba.fastjson.annotation.JSONField;

/**
 * Created by zhangyongjie on 2021/10/13 11:19 上午
 */
public class ZhijiAddCreditsReqBody {

    @JSONField(name = "SourceCode")
    private String SourceCode = "DUIBA";

    private String superId = "1000000001788051";

    @JSONField(name = "TraceId")
    private String TraceId;

    @JSONField(name = "TransactionNumber")
    private String TransactionNumber;

    @JSONField(name = "TransactionTime")
    private String TransactionTime;

    @JSONField(name = "TransactionType")
    private String TransactionType;

    @JSONField(name = "Data")
    private ZhijiAddCreditsReqData Data;

    public String getSourceCode() {
        return SourceCode;
    }

    public void setSourceCode(String sourceCode) {
        SourceCode = sourceCode;
    }

    public String getSuperId() {
        return superId;
    }

    public void setSuperId(String superId) {
        this.superId = superId;
    }

    public String getTraceId() {
        return TraceId;
    }

    public void setTraceId(String traceId) {
        TraceId = traceId;
    }

    public String getTransactionNumber() {
        return TransactionNumber;
    }

    public void setTransactionNumber(String transactionNumber) {
        TransactionNumber = transactionNumber;
    }

    public String getTransactionTime() {
        return TransactionTime;
    }

    public void setTransactionTime(String transactionTime) {
        TransactionTime = transactionTime;
    }

    public String getTransactionType() {
        return TransactionType;
    }

    public void setTransactionType(String transactionType) {
        TransactionType = transactionType;
    }

    public ZhijiAddCreditsReqData getData() {
        return Data;
    }

    public void setData(ZhijiAddCreditsReqData data) {
        Data = data;
    }
}
